importPackage(java.awt);
importPackage(java.awt.geom);
include(Resources.id('mtrsteamloco:scripts/display_helper.js'));

let slotCfg = {
    version: 1,
    texSize: [1580, 128],
    slots: [
        {
            name: 'head',
            texArea: [0, 0, 1580, 128],
            pos: [
                [
                    [-0.87, 2.82, 9.615],
                    [-0.87, 2.68, 9.615],
                    [0.87, 2.68, 9.615],
                    [0.87, 2.82, 9.615],
                ],
            ],
            offsets: [[0, 0, 0]],
        },
    ],
};

let slotReversedCfg = {
    version: 1,
    texSize: [1580, 128],
    slots: [
        {
            name: 'head-reversed',
            texArea: [0, 0, 1580, 128],
            pos: [
                [
                    [0.87, 2.82, -9.615],
                    [0.87, 2.68, -9.615],
                    [-0.87, 2.68, -9.615],
                    [-0.87, 2.82, -9.615],
                ],
            ],
            offsets: [[0, 0, 0]],
        },
    ],
};

let dhBase = new DisplayHelper(slotCfg);
let dhReversedBase = new DisplayHelper(slotReversedCfg);

function create(ctx, state, train) {
    state.pisRateLimit = new RateLimit(0.05);
    state.dh = dhBase.create();
    state.dhReversed = dhReversedBase.create();
}

function dispose(ctx, state, train) {
    state.dh.close();
    state.dhReversed.close();
}

var EMUFont = Resources.readFont(
    Resources.idRelative('mtr:models/scripts/ep2d.ttf')
);

function render(ctx, state, train) {
    if (state.pisRateLimit.shouldUpdate()) {
        let g;

        let EMUText = getDestinationStation(train);

        [
            { dh: state.dh, graphicsName: 'head' },
            { dh: state.dhReversed, graphicsName: 'head-reversed' },
        ].forEach((element) => {
            let dh = element.dh;
            g = dh.graphicsFor(element.graphicsName);
            g.setColor(new Color(0.0588235294, 0.0392156863, 0.0196078431));
            g.fillRect(0, 0, 1580, 128);
            g.setColor(new Color(0.3529411765, 1.0, 0.0274509804));
            g.setFont(EMUFont.deriveFont(Font.PLAIN, 120));
            let fontMetrics = g.getFontMetrics();
            let textWidth = fontMetrics.stringWidth(EMUText);
            g.drawString(
                EMUText,
                (1580 - textWidth) / 2,
                128
            );
            dh.upload();
        });
    }

    ctx.drawCarModel(state.dh.model, 0, null);
    ctx.drawCarModel(state.dhReversed.model, train.trainCars() - 1, null);
}

function getDestinationStation(train) {
    let stationList = train.getThisRoutePlatforms();
    let lastPlatform = stationList[stationList.size() - 1];
    if (lastPlatform === undefined) return 'ПОСАДКИ НЕТ';
    return lastPlatform.destinationName.split('\\|')[0].toUpperCase();
}
